All Classes
-
All Classes Class Summary Exception Summary Class Description HostedClientLogin ClientLoginimplementation for use inside an App Engine container.LoginException Thrown when there's an error logging in.RemoteApiException Indicates an internal exception in the remote API.RemoteApiInstaller Installs and uninstalls the remote API.RemoteApiOptions A mutable object containing settings for installing the remote API.