Class HostedClientLogin


  • public class HostedClientLogin
    extends Object
    ClientLogin implementation for use inside an App Engine container. We use URLFetchService to issue HTTP requests since that's the only way to do it from inside App Engine.
    • Constructor Detail

      • HostedClientLogin

        public HostedClientLogin()
    • Method Detail

      • login

        @Deprecated
        public List<org.apache.http.cookie.Cookie> login​(String host,
                                                         String email,
                                                         String password)
                                                  throws IOException
        Deprecated.
        ClientLogin authentication is deprecated and will soon be shut down. Use OAuth2.0 instead to obtain credentials.
        Authenticates the user using ClientLogin. This requires two HTTP requests, one to get a token from Google and one to exchange it for cookies from App Engine.
        Throws:
        IOException