RemoteApiOptions |
RemoteApiOptions.copy() |
|
RemoteApiOptions |
RemoteApiOptions.credentials(String newUserEMail,
String newPassword) |
Deprecated.
|
RemoteApiOptions |
RemoteApiOptions.datastoreQueryFetchSize(int newValue) |
When executing a datastore query, this is the number of results to fetch
per HTTP request.
|
RemoteApiOptions |
RemoteApiOptions.maxConcurrentRequests(int newValue) |
This parameter controls the maximum number of async API requests that will be
in flight at once.
|
RemoteApiOptions |
RemoteApiOptions.maxHttpResponseSize(int newValue) |
When making a remote call, this is the maximum size of the HTTP response.
|
RemoteApiOptions |
RemoteApiOptions.remoteApiPath(String newPath) |
Sets the path used to access the remote API.
|
RemoteApiOptions |
RemoteApiOptions.reuseCredentials(String newUserEmail,
String serializedCredentials) |
Reuses credentials from another AppEngineClient.
|
RemoteApiOptions |
RemoteApiOptions.server(String newHostname,
int newPort) |
Sets the host and port port where we will connect.
|
RemoteApiOptions |
RemoteApiOptions.useAccessToken(String accessToken) |
Use an access token credential.
|
RemoteApiOptions |
RemoteApiOptions.useApplicationDefaultCredential() |
Use a Google Application Default credential for authentication.
|
RemoteApiOptions |
RemoteApiOptions.useComputeEngineCredential() |
Deprecated.
|
RemoteApiOptions |
RemoteApiOptions.useDevelopmentServerCredential() |
Use credentials appropriate for talking to the Development Server.
|
RemoteApiOptions |
RemoteApiOptions.useServiceAccountCredential(String serviceAccountId,
String p12PrivateKeyFile) |
Use a service account credential.
|
RemoteApiOptions |
RemoteApiOptions.useServiceAccountCredential(String serviceAccountId,
PrivateKey privateKey) |
Use a service account credential.
|