Package com.google.appengine.tools.remoteapi
-
Class Summary Class Description HostedClientLogin ClientLoginimplementation for use inside an App Engine container.RemoteApiInstaller Installs and uninstalls the remote API.RemoteApiOptions A mutable object containing settings for installing the remote API. -
Exception Summary Exception Description LoginException Thrown when there's an error logging in.RemoteApiException Indicates an internal exception in the remote API.