Class HostedClientLogin
- java.lang.Object
-
- com.google.appengine.tools.remoteapi.HostedClientLogin
-
public class HostedClientLogin extends Object
ClientLoginimplementation for use inside an App Engine container. We useURLFetchServiceto issue HTTP requests since that's the only way to do it from inside App Engine.
-
-
Constructor Summary
Constructors Constructor Description HostedClientLogin()
-
Method Summary
All Methods Instance Methods Concrete Methods Deprecated Methods Modifier and Type Method Description List<org.apache.http.cookie.Cookie>login(String host, String email, String password)Deprecated.ClientLogin authentication is deprecated and will soon be shut down.
-
-
-
Method Detail
-
login
@Deprecated public List<org.apache.http.cookie.Cookie> login(String host, String email, String password) throws IOException
Deprecated.ClientLogin authentication is deprecated and will soon be shut down. Use OAuth2.0 instead to obtain credentials.Authenticates the user using ClientLogin. This requires two HTTP requests, one to get a token from Google and one to exchange it for cookies from App Engine.- Throws:
IOException
-
-